<template>
  <j-modal :title="title" :width="width" :visible="visible" :confirmLoading="confirmLoading" switchFullscreen
    @ok="handleOk" @cancel="handleCancel" cancelText="关闭">
    <a-spin :spinning="confirmLoading">
      <a-form-model ref="form" :model="model" :rules="validatorRules">
        <a-row>
          

          <a-col :span="24">
            <a-form-model-item label="精度参数编码" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-input v-model="model.precisionParametersNum" placeholder="请输入精度参数编码"></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span="24">
            <a-form-model-item label="精度参数名称" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-input v-model="model.precisionParametersName" placeholder="请输入精度参数名称"></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span="24">
            <a-form-model-item label="计量单位" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-input v-model="model.unit" placeholder="请输入计量单位"></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span="24">
            <a-form-model-item label="出厂精度值" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-input v-model="model.emmm" placeholder="请输入出厂精度值"></a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span="24">
            <a-form-model-item label="实际精度值" :labelCol="labelCol" :wrapperCol="wrapperCol">
              <a-input v-model="model.actualValue" placeholder="请输入实际精度值"></a-input>
            </a-form-model-item>
          </a-col>
         
        </a-row>
      </a-form-model>
    </a-spin>
    <template slot="footer">
      <a-button @click="handleOkButContinue" type="primary" :loading="addloading" v-if="title == '新增'">
        保存并继续新增
      </a-button>
      <a-button @click="handleOk" type="primary" :loading="addloading">
        保存
      </a-button>
      <a-button @click="handleCancel">
        取消
      </a-button>
    </template>
  </j-modal>
</template>
<script>
import { httpAction } from '@/api/manage'
import { validateDuplicateValue } from '@/utils/util'
import { duplicateCheck } from '@/api/api'
import { getAction, putAction } from '@/api/manage'
export default {
  name: "WarehouseModal",
  components: {
  },
  props: {
    mainId: {
      type: String,
      default: '',
      required: false
    },
    enterpriseId: {
      type: String,
      default: '',
      required: false
    },
    version: {
      type: Number,
      required: false
    }
  },
  data() {
    return {
      addloading: false,
      codeRule: 'mom_base_warehouse_code_rule',
      title: "操作",
      width: 800,
      visible: false,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      selectStatus: 1,
      isMaintenance: [
        { label: '委外', value: 'outsourcing' },
        { label: '自检', value: 'self' },
      ],
      verificationMethod: 'self',
      confirmLoading: false,
      validatorRules: {
        //  code: [
        //     { required: true, message: '请输入仓库编码!'},
        //  ],
        //  status: [
        //     { required: true, message: '是否虚拟'},
        //  ],
        //  enterpriseId: [{ required: true}],
        //  remark:[{min:0,max:255,message:'输入超过最大限制请缩减长度'}]
      },
      url: {
        add: "/eam/calibrationOrderDetail/add",
        edit: "/eam/calibrationOrderDetail/edit",
        check: "/eam/calibrationOrderDetail/check",
        ruleBaseURL: "/sys/fillRule/executeRuleByCode",
      },
      equipment_id: '',
      equipmentList: [],
      equipmentList_bf: []
    }
  },
  created() {
    //备份model原始值
    this.modelDefault = JSON.parse(JSON.stringify(this.model));
  },
  methods: {
    handleChange(e, type) {
      switch (type) {
        case 0:
          this.$set(this.model, 'status', e);
          return
        case 1:
          this.$set(this.model, 'calibrationType', e);
          return
        case 2:
          this.$set(this.model, 'equipmentId', e);
          return
      };
    },
    add() {
      this.modelDefault.status = 1
      this.modelDefault.calibrationType = 'false'
      this.equipment_id = ''
      this.modelDefault.calibrationOrderId = this.mainId
      this.edit(this.modelDefault);

    },
    async edit(record) {
      this.model = Object.assign({}, record);
      this.visible = true;
      // if (!this.model.id) {
      //   var ruleCodeParam = {
      //     enterpriseId: this.enterpriseId,
      //     version: this.version
      //   }
      //   putAction(this.url.ruleBaseURL + "/" + this.codeRule, ruleCodeParam).then(res => {
      //     this.model.code = res.result;
      //   });
      // }
    },
    close() {
      this.$emit('close');
      this.visible = false;
      this.$refs.form.clearValidate();
    },
    handleOk() {
      const that = this;
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true;
          let httpurl = '';
          let method = '';
          if (!this.model.id) {
            httpurl += this.url.add;
            method = 'post';
            if (this.version) {
              this.model.version = this.version;
            } else {
              this.model.version = 1;

            }
            this.model.enterpriseId = this.enterpriseId
            this.model.versionStatus = '0';
          } else {
            httpurl += this.url.edit;
            method = 'put';
          }
          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
            that.$emit('postAdd')
          })
        } else {
          return false
        }
      })
    },
    handleOkButContinue() {
      const that = this;
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true;
          let httpurl = '';
          let method = '';
          if (!this.model.id) {
            httpurl += this.url.add;
            method = 'post';
            if (this.version) {
              this.model.version = this.version;
            } else {
              this.model.version = 1;

            }
            this.model.enterpriseId = this.enterpriseId
            this.model.versionStatus = '0';
          } else {
            httpurl += this.url.edit;
            method = 'put';
          }
          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.$refs.form.clearValidate();
            that.$emit('handleAdd');
            that.$emit('postAdd')
          })
        } else {
          return false
        }
      })
    },
    handleCancel() {
      this.close()
    },
    validateName(rule, value, callback) {
      var params = {
      
        enterpriseId: this.enterpriseId,
        version: this.version
      };
      getAction(this.url.check, params).then(res => {
        if (res.result.length == 0) {
          callback();
        }
        else if (this.model.id ) {
          callback();
        }
        else {
          callback('仓库名称重复')
        }
      })
    },
  }
}
</script>